MuJoCo Visualizer
==================

JAXsim provides a simple interface with MuJoCo's visualizer. The visualizer is
a separate process that communicates with the main simulation process. This
allows for the simulation to run at full speed while the visualizer can run at
a different frame rate.

.. currentmodule:: jaxsim.mujoco

Loaders
~~~~~~~

.. automodule:: jaxsim.mujoco.loaders
    :members:

Model
~~~~~

.. automodule:: jaxsim.mujoco.model
    :members:

Visualizer
~~~~~~~~~~

.. automodule:: jaxsim.mujoco.visualizer
    :members:
